@@ -1,28 +1,26 @@
 import cfdm
 
-from .functions import CF
-
 from . import (
     AuxiliaryCoordinate,
-    CellMethod,
+    Bounds,
     CellMeasure,
+    CellMethod,
+    CoordinateConversion,
     CoordinateReference,
+    Count,
+    Datum,
     DimensionCoordinate,
+    Domain,
     DomainAncillary,
     DomainAxis,
     Field,
     FieldAncillary,
-    Bounds,
-    InteriorRing,
-    CoordinateConversion,
-    Datum,
-    Count,
-    List,
     Index,
+    InteriorRing,
+    List,
     NodeCountProperties,
     PartNodeCountProperties,
 )
-
 from .data import (
     Data,
     GatheredArray,
@@ -31,10 +29,11 @@ from .data import (
     RaggedIndexedArray,
     RaggedIndexedContiguousArray,
 )
+from .functions import CF
 
 
 class CFImplementation(cfdm.CFDMImplementation):
-    """TODO.
+    """A container for the CF data model implementation for `cf`.
 
     .. versionadded:: 3.0.0
 
@@ -80,6 +79,7 @@ _implementation = CFImplementation(
     CellMethod=CellMethod,
     CoordinateReference=CoordinateReference,
     DimensionCoordinate=DimensionCoordinate,
+    Domain=Domain,
     DomainAncillary=DomainAncillary,
     DomainAxis=DomainAxis,
     Field=Field,
@@ -114,7 +114,7 @@ def implementation():
         `CFImplementation`
             A container for the CF data model implementation.
 
-    **Examples:**
+    **Examples**
 
     >>> i = cf.implementation()
     >>> i
@@ -125,6 +125,7 @@ def implementation():
      'CellMethod': cf.cellmethod.CellMethod,
      'CoordinateReference': cf.coordinatereference.CoordinateReference,
      'DimensionCoordinate': cf.dimensioncoordinate.DimensionCoordinate,
+     'Domain': cf.domain.Domain,
      'DomainAncillary': cf.domainancillary.DomainAncillary,
      'DomainAxis': cf.domainaxis.DomainAxis,
      'Field': cf.field.Field,
