@@ -2,30 +2,50 @@ import logging
 
 import cfdm
 
-from .constants import cr_coordinates, cr_canonical_units, cr_default_values
-from .functions import allclose
-from .functions import inspect as cf_inspect, atol as cf_atol, rtol as cf_rtol
-from .query import Query
-
-from . import CoordinateConversion
-from . import Datum
-
+from . import CoordinateConversion, Datum
+from .constants import cr_canonical_units, cr_coordinates, cr_default_values
 from .data.data import Data
-
-from .functions import _DEPRECATION_ERROR_METHOD, _DEPRECATION_ERROR_ATTRIBUTE
-
 from .decorators import (
+    _deprecated_kwarg_check,
     _inplace_enabled,
     _inplace_enabled_define_and_cleanup,
-    _deprecated_kwarg_check,
     _manage_log_level_via_verbosity,
 )
+from .functions import (
+    _DEPRECATION_ERROR_ATTRIBUTE,
+    _DEPRECATION_ERROR_METHOD,
+    allclose,
+)
+from .functions import atol as cf_atol
+from .functions import inspect as cf_inspect
+from .functions import rtol as cf_rtol
+from .query import Query
 
 _units = {}
 
 logger = logging.getLogger(__name__)
 
 
+def _totuple(a):
+    """Return an N-d (N>0) array as a nested tuple of Python scalars.
+
+    :Parameters:
+
+        a: numpy.ndarray
+            The numpy array
+
+    :Returns:
+
+        `tuple`
+            The array as an nested tuple of Python scalars.
+
+    """
+    try:
+        return tuple(_totuple(i) for i in a)
+    except TypeError:
+        return a
+
+
 class CoordinateReference(cfdm.CoordinateReference):
     """A coordinate reference construct of the CF data model.
 
@@ -84,7 +104,7 @@ class CoordinateReference(cfdm.CoordinateReference):
     """
 
     def __new__(cls, *args, **kwargs):
-        """TODO."""
+        """Store component classes."""
         instance = super().__new__(cls)
         instance._CoordinateConversion = CoordinateConversion
         instance._Datum = Datum
@@ -191,7 +211,7 @@ class CoordinateReference(cfdm.CoordinateReference):
         """Returns False since coordinate reference constructs do not
         have cell bounds.
 
-        **Examples:**
+        **Examples**
 
         >>> c.has_bounds()
         False
@@ -244,7 +264,7 @@ class CoordinateReference(cfdm.CoordinateReference):
             `Units` or `None`
                 The canonical units, or `None` if there are not any.
 
-        **Examples:**
+        **Examples**
 
         >>> cf.CoordinateReference.canonical_units('perspective_point_height')
         <Units: m>
@@ -262,7 +282,7 @@ class CoordinateReference(cfdm.CoordinateReference):
 
             `None`
 
-        **Examples:**
+        **Examples**
 
         >>> c.close()
 
@@ -283,7 +303,7 @@ class CoordinateReference(cfdm.CoordinateReference):
 
                 The default value, or 0.0 if one is not available.
 
-        **Examples:**
+        **Examples**
 
         >>> cf.CoordinateReference.default_value('ptop')
         0.0
@@ -320,7 +340,7 @@ class CoordinateReference(cfdm.CoordinateReference):
             out: `bool`
                 Whether or not the two objects are equivalent.
 
-        **Examples:**
+        **Examples**
 
         >>> a = cf.example_field(6)
         >>> b = cf.example_field(7)
@@ -342,11 +362,9 @@ class CoordinateReference(cfdm.CoordinateReference):
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
             logger.info(
-                "{}: Different types ({!r} != {!r})".format(
-                    self.__class__.__name__,
-                    self.__class__.__name__,
-                    other.__class__.__name__,
-                )
+                f"{self.__class__.__name__}: Different types "
+                f"({self.__class__.__name__!r} != "
+                f"{other.__class__.__name__!r})"
             )  # pragma: no cover
             return False
 
@@ -355,9 +373,8 @@ class CoordinateReference(cfdm.CoordinateReference):
         # ------------------------------------------------------------
         if self.identity() != other.identity():
             logger.info(
-                "{}: Different identities ({!r} != {!r})".format(
-                    self.__class__.__name__, self.identity(), other.identity()
-                )
+                f"{self.__class__.__name__}: Different identities "
+                f"({self.identity()!r} != {other.identity()!r})"
             )  # pragma: no cover
             return False
 
@@ -368,9 +385,8 @@ class CoordinateReference(cfdm.CoordinateReference):
         ancillaries1 = other.coordinate_conversion.domain_ancillaries()
         if set(ancillaries0) != set(ancillaries1):
             logger.info(
-                "{}: Non-equivalent domain ancillary terms".format(
-                    self.__class__.__name__
-                )
+                f"{self.__class__.__name__}: Non-equivalent domain ancillary "
+                "terms"
             )  # pragma: no cover
             return False
 
@@ -378,8 +394,8 @@ class CoordinateReference(cfdm.CoordinateReference):
         for term, value0 in ancillaries0.items():
             if (value0 is None) != (ancillaries1[term] is None):
                 logger.info(
-                    "{}: Non-equivalent domain ancillary-valued "
-                    "term {!r}".format(self.__class__.__name__, term)
+                    f"{self.__class__.__name__}: Non-equivalent domain "
+                    f"ancillary-valued term {term!r}"
                 )  # pragma: no cover
                 return False
 
@@ -413,8 +429,8 @@ class CoordinateReference(cfdm.CoordinateReference):
 
             if not allclose(value0, value1, rtol=rtol, atol=atol):
                 logger.info(
-                    "{}: Non-equivalent coordinate conversion parameter-"
-                    "valued term {!r}".format(self.__class__.__name__, term)
+                    f"{self.__class__.__name__}: Non-equivalent coordinate "
+                    f"conversion parameter-valued term {term!r}"
                 )  # pragma: no cover
                 return False
 
@@ -439,8 +455,8 @@ class CoordinateReference(cfdm.CoordinateReference):
 
             if not allclose(value0, value1, rtol=rtol, atol=atol):
                 logger.info(
-                    "{}: Non-equivalent datum parameter-valued "
-                    "term {!r}".format(self.__class__.__name__, term)
+                    f"{self.__class__.__name__}: Non-equivalent datum "
+                    f"parameter-valued term {term!r}"
                 )  # pragma: no cover
                 return False
 
@@ -528,7 +544,7 @@ class CoordinateReference(cfdm.CoordinateReference):
                 Whether or not the coordinate reference matches one of the
                 given identities.
 
-        **Examples:**
+        **Examples**
 
         >>> c.match_by_identity('time')
 
@@ -603,7 +619,7 @@ class CoordinateReference(cfdm.CoordinateReference):
 
             `None`
 
-        **Examples:**
+        **Examples**
 
         >>> r = cf.CoordinateReference('atmosphere_hybrid_height_coordinate',
         ...                             a='ncvar:ak',
@@ -709,6 +725,14 @@ class CoordinateReference(cfdm.CoordinateReference):
                     # Do not add a default value to the structural signature
                     continue
 
+                # Convert value to a Python scalar if it's 0-d, or a
+                # tuple if it's N-d.
+                value = value.array
+                if not value.ndim:
+                    value = value.item()
+                else:
+                    value = _totuple(value)
+
                 append(
                     (
                         component + ":" + term,
