@@ -3,8 +3,7 @@ from operator import mul
 
 import numpy
 
-from ..functions import parse_indices, get_subspace
-
+from ..functions import get_subspace, parse_indices
 from . import abstract
 
 
