@@ -1,11 +1,9 @@
 import numpy
 
-from ..functions import parse_indices, get_subspace
-from .functions import _open_um_file, _close_um_file
-
+from ..functions import get_subspace, parse_indices
 from ..umread_lib.umfile import Rec
-
 from . import abstract
+from .functions import _close_um_file, _open_um_file
 
 
 class UMArray(abstract.FileArray):
@@ -305,6 +303,3 @@ class UMArray(abstract.FileArray):
             word_size=self.word_size,
             byte_ordering=self.byte_ordering,
         )
-
-
-# --- End: class
