@@ -331,7 +331,7 @@ class Query:
         attr = ".".join(self._attr)
 
         if not self._compound:
-            out = f"{attr}({self._operator} " + str(self._value)
+            out = f"{attr}({self._operator} {self._value!s})"
         else:
             bitwise_operator = repr(self._bitwise_operator)
             if "and_" in bitwise_operator:
@@ -348,30 +348,27 @@ class Query:
 
     @property
     def attr(self):
-        """TODO.
+        """The object attribute on which to apply the query condition.
 
-        **Examples:**
+        **Examples**
 
         >>> q = cf.Query('ge', 4)
         >>> print(q.attr)
-        None
+        ()
         >>> q = cf.Query('le', 6, attr='year')
         >>> q.attr
-        'year'
-        >>> q.addattr('foo')
-        >>> q.attr
-        'year'asdasdas TODO
+        ('year',)
 
         """
         return self._attr
 
     @property
     def operator(self):
-        """TODO.
+        """The query operator.
 
         Compound conditions return `None`.
 
-        **Examples:**
+        **Examples**
 
         >>> q = cf.Query('ge', 4)
         >>> q.operator
@@ -385,11 +382,11 @@ class Query:
 
     @property
     def value(self):
-        """TODO.
+        """The value of the condition encapsulated by the query.
 
         An exception is raised for compound conditions.
 
-        **Examples:**
+        **Examples**
 
         >>> q = cf.Query('ge', 4)
         >>> q.value
@@ -422,7 +419,7 @@ class Query:
             `Query`
                 The new query object.
 
-        **Examples:**
+        **Examples**
 
         >>> q = cf.eq(2001)
         >>> q
@@ -460,7 +457,7 @@ class Query:
 
                 The deep copy.
 
-        **Examples:**
+        **Examples**
 
         >>> r = q.copy()
 
@@ -492,7 +489,7 @@ class Query:
     @_deprecated_kwarg_check("traceback")
     @_manage_log_level_via_verbosity
     def equals(self, other, verbose=None, traceback=False):
-        """TODO."""
+        """True if two `Query` objects are the same."""
         standard_difference_message = (
             f"{self.__class__.__name__}: Different compound components"
         )
@@ -566,7 +563,7 @@ class Query:
                 The result of the query. The nature of the result is
                 dependent on the object type of *x*.
 
-        **Examples:**
+        **Examples**
 
         >>> q = cf.Query('lt', 5.5)
         >>> q.evaluate(6)
@@ -776,7 +773,7 @@ def lt(value, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> c = cf.lt(5)
     >>> c == 2
@@ -837,7 +834,7 @@ def le(value, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.le(5)
     >>> q
@@ -881,7 +878,7 @@ def gt(value, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.gt(5)
     >>> q
@@ -925,7 +922,7 @@ def ge(value, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.ge(5)
     >>> q
@@ -980,7 +977,7 @@ def eq(value, units=None, attr=None, exact=True):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.eq(5)
     >>> q
@@ -1040,7 +1037,7 @@ def ne(value, units=None, attr=None, exact=True):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.ne(5)
     >>> q
@@ -1092,7 +1089,7 @@ def wi(value0, value1, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.wi(5, 7)
     >>> q
@@ -1139,7 +1136,7 @@ def wo(value0, value1, units=None, attr=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> q = cf.wo(5)
     >>> q
@@ -1186,7 +1183,7 @@ def set(values, units=None, attr=None, exact=True):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> c = cf.set([3, 5])
     >>> c == 4
@@ -1230,7 +1227,7 @@ def contains(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.contains(8)
     <CF Query: [lower_bounds(le 8) & upper_bounds(ge 8)]>
@@ -1274,7 +1271,7 @@ def year(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16)
     >>> d == cf.year(2002)
@@ -1310,7 +1307,7 @@ def month(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16)
     >>> d == cf.month(6)
@@ -1346,7 +1343,7 @@ def day(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16)
     >>> d == cf.day(16)
@@ -1403,7 +1400,7 @@ def hour(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16, 18)
     >>> d == cf.hour(18)
@@ -1439,7 +1436,7 @@ def minute(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16, 18, 30, 0)
     >>> d == cf.minute(30)
@@ -1475,7 +1472,7 @@ def second(value):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> d = cf.dt(2002, 6, 16, 18, 30, 0)
     >>> d == cf.second(0)
@@ -1517,7 +1514,7 @@ def cellsize(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.cellsize(cf.lt(5, 'km'))
     <CF Query: cellsize(lt <CF Data: 5 km>)>
@@ -1525,8 +1522,6 @@ def cellsize(value, units=None):
     <CF Query: cellsize(eq 5)>
     >>> cf.cellsize(cf.Data(5, 'km'))
     <CF Query: cellsize(eq <CF Data: 5 km>)>
-    >>> cf.cellsize(cf.Data(5, 'km'))
-    <CF Query: cellsize(eq <CF Data: 5 km>)>
     >>> cf.cellsize(5, units='km')
     <CF Query: cellsize(eq <CF Data: 5 km>)>
 
@@ -1561,9 +1556,16 @@ def cellwi(value0, value1, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.cellwi(cf.Data(5, 'km'), cf.Data(10, 'km'))
+    <CF Query: [lower_bounds(ge 5 km) & upper_bounds(le 10 km)]>
+    >>> cf.cellwi(5, 10, units="km")
+    <CF Query: [lower_bounds(ge 5 km) & upper_bounds(le 10 km)]>
+    >>> cf.cellwi(cf.Data(5, 'km'), cf.Data(10000, 'm'))
+    <CF Query: [lower_bounds(ge 5 km) & upper_bounds(le 10000 m)]>
+    >>> cf.cellwi(0.2, 0.3)
+    <CF Query: [lower_bounds(ge 0.2) & upper_bounds(le 0.3)]>
 
     """
     return Query("ge", value0, units=units, attr="lower_bounds") & Query(
@@ -1595,9 +1597,16 @@ def cellwo(value0, value1, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.cellwo(cf.Data(5, 'km'), cf.Data(10, 'km'))
+    <CF Query: [lower_bounds(lt 5 km) & upper_bounds(gt 10 km)]>
+    >>> cf.cellwo(5, 10, units="km")
+    <CF Query: [lower_bounds(lt 5 km) & upper_bounds(gt 10 km)]>
+    >>> cf.cellwo(cf.Data(5, 'km'), cf.Data(10000, 'm'))
+    <CF Query: [lower_bounds(lt 5 km) & upper_bounds(gt 10000 m)]>
+    >>> cf.cellwo(0.2, 0.3)
+    <CF Query: [lower_bounds(lt 0.2) & upper_bounds(gt 0.3)]>
 
     """
     return Query("lt", value0, units=units, attr="lower_bounds") & Query(
@@ -1630,9 +1639,14 @@ def cellgt(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.cellgt(cf.Data(300, 'K'))
+    <CF Query: lower_bounds(gt 300 K)>
+    >>> cf.cellgt(300, units='K')
+    <CF Query: lower_bounds(gt 300 K)>
+    >>> cf.cellgt(300)
+    <CF Query: lower_bounds(gt 300)>
 
     """
     return Query("gt", value, units=units, attr="lower_bounds")
@@ -1664,9 +1678,14 @@ def cellge(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.cellge(cf.Data(300, 'K'))
+    <CF Query: lower_bounds(ge 300 K)>
+    >>> cf.cellge(cf.Data(300, 'K'))
+    <CF Query: lower_bounds(ge 300 K)>
+    >>> cf.cellge(300)
+    <CF Query: lower_bounds(ge 300)>
 
     """
     return Query("ge", value, units=units, attr="lower_bounds")
@@ -1697,9 +1716,14 @@ def celllt(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.celllt(cf.Data(300, 'K'))
+    <CF Query: upper_bounds(lt 300 K)>
+    >>> cf.celllt(300, units='K')
+    <CF Query: upper_bounds(lt 300 K)>
+    >>> cf.celllt(300)
+    <CF Query: upper_bounds(lt 300)>
 
     """
     return Query("lt", value, units=units, attr="upper_bounds")
@@ -1730,9 +1754,14 @@ def cellle(value, units=None):
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
-    TODO
+    >>> cf.cellle(cf.Data(300, 'K'))
+    <CF Query: upper_bounds(le 300 K)>
+    >>> cf.cellle(300, units='K')
+    <CF Query: upper_bounds(le 300 K)>
+    >>> cf.cellle(300)
+    <CF Query: upper_bounds(le 300)>
 
     """
     return Query("le", value, units=units, attr="upper_bounds")
@@ -1753,7 +1782,7 @@ def jja():
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> f
     <CF Field: air_temperature(time(365), latitude(64), longitude(128)) K>
@@ -1779,7 +1808,7 @@ def son():
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> f
     <CF Field: air_temperature(time(365), latitude(64), longitude(128)) K>
@@ -1805,7 +1834,7 @@ def djf():
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> f
     <CF Field: air_temperature(time(365), latitude(64), longitude(128)) K>
@@ -1832,7 +1861,7 @@ def mam():
         `Query`
             The query object.
 
-    **Examples:**
+    **Examples**
 
     >>> f
     <CF Field: air_temperature(time(365), latitude(64), longitude(128)) K>
@@ -1874,7 +1903,7 @@ def seasons(n=4, start=12):
         `list` of `Query`
             The query objects.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.seasons()
     [<CF Query: month[(ge 12) | (le 2)]>,
