@@ -1,24 +1,27 @@
 import datetime
+import faulthandler
 import unittest
 
+faulthandler.enable()  # to debug seg faults and timeouts
+
 import cf
 
 
 class DomainAxisTest(unittest.TestCase):
     def test_DomainAxis__repr__str(self):
         x = cf.DomainAxis(size=56)
-        x.nc_set_dimension('tas')
+        x.nc_set_dimension("tas")
 
-        _ = repr(x)
-        _ = str(x)
+        repr(x)
+        str(x)
 
     def test_DomainAxis(self):
         x = cf.DomainAxis(size=111)
-        x.nc_set_dimension('tas')
+        x.nc_set_dimension("tas")
 
         self.assertEqual(x.size, 111)
         del x.size
-        self.assertIsNone(getattr(x, 'size', None))
+        self.assertIsNone(getattr(x, "size", None))
         x.size = 56
         self.assertEqual(x.size, 56)
         self.assertEqual(x, 56)
@@ -42,13 +45,11 @@ class DomainAxisTest(unittest.TestCase):
         self.assertLessEqual(x, 100)
         self.assertNotEqual(x, 100)
 
-        _ = hash(x)
-
-# --- End: class
+        hash(x)
 
 
-if __name__ == '__main__':
-    print('Run date:', datetime.datetime.now())
+if __name__ == "__main__":
+    print("Run date:", datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
