@@ -14,7 +14,6 @@ faulthandler.enable()  # to debug seg faults and timeouts
 
 import cf
 
-
 n_tmpfiles = 8
 tmpfiles = [
     tempfile.mkstemp("_test_read_write.nc", dir=os.getcwd())[1]
@@ -33,7 +32,7 @@ tmpfiles = [
 
 
 def _remove_tmpfiles():
-    """TODO."""
+    """Try to remove defined temporary files by deleting their paths."""
     for f in tmpfiles:
         try:
             os.remove(f)
@@ -345,12 +344,6 @@ class read_writeTest(unittest.TestCase):
                 if fmt == "NETCDF4_CLASSIC" and ex_field_n in (6, 7):
                     continue
 
-                # Skip since "Can't write int64 data from <Count: (2) > to a
-                # NETCDF3_CLASSIC file" causes a ValueError i.e. not possible.
-                # Note: can remove this when Issue #140 is closed.
-                if fmt in self.netcdf3_fmts and ex_field_n == 6:
-                    continue
-
                 cf.write(ex_field, tmpfile, fmt=fmt, mode="a")
                 f = cf.read(tmpfile)
 
@@ -421,9 +414,6 @@ class read_writeTest(unittest.TestCase):
             cf.write(g, tmpfile, fmt=fmt, mode="w")  # 1. overwrite to wipe
             append_ex_fields = cf.example_fields()
             del append_ex_fields[1]  # note: can remove after Issue #141 closed
-            # Note: can remove this del when Issue #140 is closed:
-            if fmt in self.netcdf3_fmts:
-                del append_ex_fields[5]  # n=6 ex_field, minus 1 for above del
             if fmt in "NETCDF4_CLASSIC":
                 # Remove n=6 and =7 for reasons as given above (del => minus 1)
                 append_ex_fields = append_ex_fields[:5]
@@ -746,6 +736,59 @@ class read_writeTest(unittest.TestCase):
         with self.assertRaises(Exception):
             cf.read("test_read_write.py")
 
+    def test_read_cdl_string(self):
+        """Test the `cdl_string` keyword of the `read` function."""
+        # Test CDL in full, header-only and coordinate-only type:
+        tempfile_to_option_mapping = {
+            tmpfile: None,
+            tmpfileh: "-h",
+            tmpfilec: "-c",
+        }
+
+        for tempf, option in tempfile_to_option_mapping.items():
+            # Set up the CDL string to test...
+            command_to_run = ["ncdump", self.filename, ">", tempf]
+            if option:
+                command_to_run.insert(1, option)
+            subprocess.run(
+                " ".join(command_to_run),
+                shell=True,
+                check=True,
+            )
+            with open(tempf, "r") as file:
+                cdl_string_1 = file.read()
+
+            # ... and now test it as an individual string input
+            f_from_str = cf.read(cdl_string_1, cdl_string=True)
+            f_from_file = cf.read(tempf)  # len 1 so only one field to check
+            self.assertEqual(len(f_from_str), len(f_from_file))
+            self.assertEqual(f_from_str[0], f_from_file[0])
+
+            # ... and test further by inputting it in duplicate as a sequence
+            f_from_str = cf.read([cdl_string_1, cdl_string_1], cdl_string=True)
+            f_from_file = cf.read(tempf)  # len 1 so only one field to check
+            self.assertEqual(len(f_from_str), 2 * len(f_from_file))
+            self.assertEqual(f_from_str[0], f_from_file[0])
+            self.assertEqual(f_from_str[1], f_from_file[0])
+
+            # Check compatibility with the `fmt` kwarg.
+            f0 = cf.read(cdl_string_1, cdl_string=True, fmt="CDL")  # fine
+            self.assertEqual(len(f0), len(f_from_file))
+            self.assertEqual(f0[0], f_from_file[0])
+            # If the 'fmt' and 'cdl_string' values contradict each other,
+            # alert the user to this. Note that the default fmt is None but
+            # it then gets interpreted as NETCDF, so default fmt is fine and
+            # it is tested in f_from_str above where fmt is not set.
+            with self.assertRaises(ValueError):
+                f0 = cf.read(cdl_string_1, cdl_string=True, fmt="NETCDF")
+
+        # If the user forgets the cdl_string=True argument they will
+        # accidentally attempt to create a file with a very long name of
+        # the CDL string, which will in most, if not all, cases result in
+        # an "OSError: [Errno 36] File name too long" error:
+        with self.assertRaises(OSError):
+            cf.read(cdl_string_1)
+
     def test_read_write_string(self):
         f = cf.read(self.string_filename)
 
@@ -755,11 +798,11 @@ class read_writeTest(unittest.TestCase):
             j = i + n
             self.assertTrue(
                 f[i].data.equals(f[j].data, verbose=1),
-                "{!r} {!r}".format(f[i], f[j]),
+                f"{f[i]!r} {f[j]!r}",
             )
             self.assertTrue(
                 f[j].data.equals(f[i].data, verbose=1),
-                "{!r} {!r}".format(f[j], f[i]),
+                f"{f[j]!r} {f[i]!r}",
             )
 
         # Note: Don't loop round all netCDF formats for better
@@ -781,6 +824,61 @@ class read_writeTest(unittest.TestCase):
         f = cf.read(self.broken_bounds, verbose=0)
         self.assertEqual(len(f), 2)
 
+    def test_write_coordinates(self):
+        f = cf.example_field(0)
+
+        cf.write(f, tmpfile, coordinates=True)
+        g = cf.read(tmpfile)
+
+        self.assertEqual(len(g), 1)
+        self.assertTrue(g[0].equals(f))
+
+    def test_read_write_domain(self):
+        f = cf.read(self.filename)[0]
+        d = f.domain
+
+        # 1 domain
+        cf.write(d, tmpfile)
+        e = cf.read(tmpfile)
+        self.assertIsInstance(e, cf.FieldList)
+        self.assertTrue(len(e), 10)
+
+        e = cf.read(tmpfile, domain=True, verbose=1)
+        self.assertEqual(len(e), 1)
+        self.assertIsInstance(e, cf.DomainList)
+        e = e[0]
+        self.assertIsInstance(e, cf.Domain)
+        self.assertTrue(e.equals(e.copy(), verbose=3))
+        self.assertTrue(d.equals(e, verbose=3))
+        self.assertTrue(e.equals(d, verbose=3))
+
+        # 1 field and 1 domain
+        cf.write([f, d], tmpfile)
+        g = cf.read(tmpfile)
+        self.assertTrue(len(g), 1)
+        g = g[0]
+        self.assertIsInstance(g, cf.Field)
+        self.assertTrue(g.equals(f, verbose=3))
+
+        e = cf.read(tmpfile, domain=True, verbose=1)
+        self.assertEqual(len(e), 1)
+        e = e[0]
+        self.assertIsInstance(e, cf.Domain)
+
+        # 1 field and 2 domains
+        cf.write([f, d, d], tmpfile)
+        g = cf.read(tmpfile)
+        self.assertTrue(len(g), 1)
+        g = g[0]
+        self.assertIsInstance(g, cf.Field)
+        self.assertTrue(g.equals(f, verbose=3))
+
+        e = cf.read(tmpfile, domain=True, verbose=1)
+        self.assertEqual(len(e), 2)
+        self.assertIsInstance(e[0], cf.Domain)
+        self.assertIsInstance(e[1], cf.Domain)
+        self.assertTrue(e[0].equals(e[1]))
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
