@@ -1,9 +1,10 @@
 import datetime
 import faulthandler
 import os
-import pycodestyle
 import unittest
 
+import pycodestyle
+
 faulthandler.enable()  # to debug seg faults and timeouts
 
 import cf
@@ -78,7 +79,7 @@ class styleTest(unittest.TestCase):
         self.assertEqual(
             pep8_issues,
             0,
-            "Detected {!s} PEP8 errors or warnings:".format(pep8_issues),
+            f"Detected {pep8_issues!s} PEP8 errors or warnings:",
         )
 
 
